@@ -54,7 +54,7 @@ namespace Config {
 								"#* Use withespace \" \" as separator between different presets.\n"
 								"#* Example: \"cpu:0:default,mem:0:tty,proc:1:default cpu:0:braille,proc:0:tty\""},
 
-		{"vim_keys",			"#* Set to True to enable \"h,j,k,l\" keys for directional control in lists.\n"
+		{"vim_keys",			"#* Set to True to enable \"h,j,k,l,g,G\" keys for directional control in lists.\n"
 								"#* Conflicting keys for h:\"help\" and k:\"kill\" is accessible while holding shift."},
 
 		{"rounded_corners",		"#* Rounded corners on boxes, is ignored if TTY mode is ON."},
@@ -77,8 +77,8 @@ namespace Config {
 
 		{"update_ms", 			"#* Update time in milliseconds, recommended 2000 ms or above for better sample times for graphs."},
 
-		{"proc_sorting",		"#* Processes sorting, \"pid\" \"program\" \"arguments\" \"threads\" \"user\" \"memory\" \"cpu lazy\" \"cpu responsive\",\n"
-								"#* \"cpu lazy\" sorts top process over time (easier to follow), \"cpu responsive\" updates top process directly."},
+		{"proc_sorting",		"#* Processes sorting, \"pid\" \"program\" \"arguments\" \"threads\" \"user\" \"memory\" \"cpu lazy\" \"cpu direct\",\n"
+								"#* \"cpu lazy\" sorts top process over time (easier to follow), \"cpu direct\" updates top process directly."},
 
 		{"proc_reversed",		"#* Reverse sorting order, True or False."},
 
@@ -141,6 +141,8 @@ namespace Config {
 
 		{"mem_below_net",		"#* Show mem box below net box instead of above."},
 
+		{"zfs_arc_cached",		"#* Count ZFS ARC in cached and available memory."},
+
 		{"show_swap", 			"#* If swap memory should be shown in memory box."},
 
 		{"swap_disk", 			"#* Show swap as a disk, ignores show_swap value above, inserts itself after first disk."},
@@ -230,6 +232,7 @@ namespace Config {
 		{"background_update", true},
 		{"mem_graphs", true},
 		{"mem_below_net", false},
+		{"zfs_arc_cached", true},
 		{"show_swap", true},
 		{"swap_disk", true},
 		{"show_disks", true},
@@ -240,7 +243,7 @@ namespace Config {
 		{"base_10_sizes", false},
 		{"io_graph_combined", false},
 		{"net_auto", true},
-		{"net_sync", false},
+		{"net_sync", true},
 		{"show_battery", true},
 		{"vim_keys", false},
 		{"tty_mode", false},
