@@ -490,6 +490,15 @@ namespace Menu {
 				"",
 				"Example:",
 				"\"exclude=/boot /home/user\""},
+			{"zfs_arc_cached",
+				"(Linux) Count ZFS ARC as cached memory.",
+				"",
+				"Add ZFS ARC used to cached memory and",
+				"ZFS ARC available to available memory.",
+				"These are otherwise reported by the Linux",
+				"kernel as used memory.",
+				"",
+				"True or False."},
 		},
 		{
 			{"graph_symbol_net",
@@ -550,10 +559,10 @@ namespace Menu {
 				"Possible values:",
 				"\"pid\", \"program\", \"arguments\", \"threads\",",
 				"\"user\", \"memory\", \"cpu lazy\" and",
-				"\"cpu responsive\".",
+				"\"cpu direct\".",
 				"",
 				"\"cpu lazy\" updates top process over time.",
-				"\"cpu responsive\" updates top process",
+				"\"cpu direct\" updates top process",
 				"directly."},
 			{"proc_reversed",
 				"Reverse processes sorting order.",
