@@ -266,20 +266,25 @@ namespace Cpu {
 	}
 
 	void update_sensors() {
-		int temp;
-		size_t size = sizeof(temp);
-		sysctlbyname("hw.acpi.thermal.tz0.temperature", &temp, &size, NULL, 0);
-		temp = (temp - 2732) / 10; // since it's an int, it's multiplied by 10, and offset to absolute zero...
-		current_cpu.temp.at(0).push_back(temp);
-		if (current_cpu.temp.at(0).size() > 20)
-			current_cpu.temp.at(0).pop_front();
+		int temp = 0;
+		int p_temp = 0;
+		int found = 0;
+		bool got_package = false;
+		size_t size = sizeof(p_temp);
+		if (sysctlbyname("hw.acpi.thermal.tz0.temperature", &p_temp, &size, NULL, 0) >= 0) {
+			got_package = true;
+			p_temp = (p_temp - 2732) / 10; // since it's an int, it's multiplied by 10, and offset to absolute zero...
+		}
 
+		size = sizeof(temp);
 		for (int i = 0; i < Shared::coreCount; i++) {
 			string s = "dev.cpu." + std::to_string(i) + ".temperature";
-			if (sysctlbyname(s.c_str(), &temp, &size, NULL, 0) < 0) {
-				Logger::warning("Could not get temp sensor - maybe you need to load the coretemp module");
-			} else {
+			if (sysctlbyname(s.c_str(), &temp, &size, NULL, 0) >= 0) {
 				temp = (temp - 2732) / 10;
+				if (not got_package) {
+					p_temp += temp;
+					found++;
+				}
 				if (cmp_less(i + 1, current_cpu.temp.size())) {
 					current_cpu.temp.at(i + 1).push_back(temp);
 					if (current_cpu.temp.at(i + 1).size() > 20)
@@ -288,6 +293,11 @@ namespace Cpu {
 			}
 		}
 
+		if (not got_package) p_temp /= found;
+		current_cpu.temp.at(0).push_back(p_temp);
+		if (current_cpu.temp.at(0).size() > 20)
+			current_cpu.temp.at(0).pop_front();
+
 	}
 
 	string get_cpuHz() {
@@ -1201,12 +1211,16 @@ namespace Proc {
 					new_proc.name = kproc->ki_comm;
 					char** argv = kvm_getargv(kd(), kproc, 0);
 					if (argv) {
-						for (int i = 0; argv[i]; i++) {
+						for (int i = 0; argv[i] and cmp_less(new_proc.cmd.size(), 1000); i++) {
 							new_proc.cmd += argv[i] + " "s;
 						}
 						if (not new_proc.cmd.empty()) new_proc.cmd.pop_back();
 					}
 					if (new_proc.cmd.empty()) new_proc.cmd = new_proc.name;
+					if (new_proc.cmd.size() > 1000) {
+						new_proc.cmd.resize(1000);
+						new_proc.cmd.shrink_to_fit();
+					}
 					new_proc.ppid = kproc->ki_ppid;
 					new_proc.cpu_s = round(kproc->ki_start.tv_sec);
 					struct passwd *pwd = getpwuid(kproc->ki_uid);
@@ -1303,7 +1317,7 @@ namespace Proc {
 			filter_found = 0;
 			for (auto &p : current_procs) {
 				if (not tree and not filter.empty()) {
-					if (not s_contains(to_string(p.pid), filter) and not s_contains(p.name, filter) and not s_contains(p.cmd, filter) and not s_contains(p.user, filter)) {
+					if (not s_contains_ic(to_string(p.pid), filter) and not s_contains_ic(p.name, filter) and not s_contains_ic(p.cmd, filter) and not s_contains_ic(p.user, filter)) {
 						p.filtered = true;
 						filter_found++;
 					} else {
